from flask import Blueprint, jsonify, request, session
from kafka import KafkaConsumer
import json

show_reviews_bp = Blueprint("showReviews", __name__)

# Kafka consumer configuration
consumer_conf = {
    "bootstrap_servers": "localhost:9092",
    "group_id": "show_reviews_group",  # Specify a unique group ID for this consumer
    "auto_offset_reset": "earliest"    # Start consuming from the beginning of the topic
}

# Function to consume reviews from Kafka
def consume_reviews(num_reviews=1):
    consumer = KafkaConsumer("customer_reviews", **consumer_conf)
    reviews = []
    
    # Iterate over messages received by the consumer
    for message in consumer:
        # Decode the message from bytes to a string using UTF-8 encoding
        review_data_str = message.value.decode("utf-8")
        
        # Parse the JSON-encoded message to extract the review data
        review_data = json.loads(review_data_str)
        
        # Append the review data to the list of reviews
        reviews.append(review_data)
        
        # Exit the loop after consuming the specified number of reviews
        if len(reviews) >= num_reviews:
            break

    # Close the consumer to release resources
    consumer.close()

    return reviews

# Route to show reviews for a user
@show_reviews_bp.route("/user/showReviews", methods=["POST"])
def show_reviews():
    # Collect user id from session
    user_id = session.get("user_id")

    if user_id:  # Check if user is logged in
        if request.method == 'POST':
            # Call function to consume reviews
            reviews = consume_reviews()

            return jsonify(reviews)
        else:
            return {"message": "null"}
    else:
        return {"error": "User not logged in"}
